Learn R Programming

tdcmStan (version 3.0.0)

shard_calculator: Calculate the Number of Shards and Simultaneous Chains

Description

Calculating the number of shards and simultaneous chains.

Usage

shard_calculator(num_respondents, num_responses, num_chains)

Value

`ret` A list containing the number of shards to use within each chain and the number of chains to run in parallel.

Arguments

num_respondents

An integer specifying the number of respondents.

num_responses

An integer specifying the number of responses.

num_chains

An integer specifying the number of chains that need to be run.

Examples

Run this code
shard_calculator(num_respondents = 1000, num_responses = 5000, num_chains = 4)

Run the code above in your browser using DataLab