powered by
Calculating the number of shards and simultaneous chains.
shard_calculator(num_respondents, num_responses, num_chains)
`ret` A list containing the number of shards to use within each chain and the number of chains to run in parallel.
An integer specifying the number of respondents.
An integer specifying the number of responses.
An integer specifying the number of chains that need to be run.
shard_calculator(num_respondents = 1000, num_responses = 5000, num_chains = 4)
Run the code above in your browser using DataLab